=======
History
=======

v0.3.2 (2018-12-02)
-------------------

- Fixed building of docs.
- Removed stickler.
- Version double increment due to pypi naming conflict.

v0.3.0 (2018-11-30)
-------------------

- Converted all damping to decimal.
- Added tests for KishidaSoilType.
- Added tests against Deepsoil.

v0.0.1 (2016-04-30)
-------------------

- First release on PyPI.
